import * as enhancedResolve from "enhanced-resolve";
import * as normalize from "normalize-package-data";
export interface Package extends normalize.Package {
    bundledDependencies?: {
        [name: string]: string;
    };
}
export interface Options {
    source: string;
    executeDirectory: string;
    stripBasePath?: string;
}
export declare type TsConfig = any;
export interface ExtendResolveOption {
    tsConfig?: TsConfig;
    exclude?: string;
    includeOnly?: string;
}
export declare type ResolveOption = enhancedResolve.ResolverFactory.ResolverOption & ExtendResolveOption;
export declare type DependencyTypes = "local" | "core" | "npm" | "npm-dev" | "undetermined";
export declare type ModuleSystem = "cjs" | "amd" | "es6" | "tsd";
export interface ExtractObject {
    module: string;
    moduleSystem: ModuleSystem;
}
export interface ResolvedModule {
    resolved?: string[];
    module: string;
    moduleSystem: ModuleSystem;
    coreModule: boolean;
    couldNotResolve?: boolean;
}
export interface BaseDependencyProperties {
    resolved: string | undefined;
    followable: boolean;
    module: string;
    moduleSystem: ModuleSystem;
    matchesDoNotFollow: boolean;
    license?: string;
    couldNotResolve: boolean;
    dependencyTypes: DependencyTypes[];
}
export interface ResolvedCoreDependency extends BaseDependencyProperties {
    resolved: string;
    coreModule: true;
    couldNotResolve: false;
}
export interface NotResolvedDependency extends BaseDependencyProperties {
    resolved: undefined;
    coreModule: false;
    couldNotResolve: true;
}
export interface ResolvedDependency extends BaseDependencyProperties {
    coreModule: boolean;
}
export declare type Dependency = ResolvedDependency | NotResolvedDependency | ResolvedCoreDependency;
export interface InputSourceDependency {
    source: string;
    dependencies: Dependency[];
}
export declare type FlatDependencies = InputSourceDependency[];
export interface ViewSourceDependency {
    source: string;
    dependencies: Dependency[];
    circular: string[];
}
export interface TreeData extends ResolvedDependency {
    circular: string[];
    children: TreeData[];
}
export interface CsrProps {
    flatDependencies: FlatDependencies;
}
export interface Project {
    name: string;
    path: string;
}
export interface StaticConfig {
    projects: Project[];
}
